@@ -9,8 +9,8 @@ import jk_pwdinput
 
 class InteractivePasswordProvider(object):
 
-	def __init__(self, enterPasswordMsg:str = "Please enter password for {0}@{1}: "):
-		self.enterPasswordMsg = enterPasswordMsg
+	def __init__(self, enterPasswordMsg:str = None):
+		self.enterPasswordMsg = enterPasswordMsg if enterPasswordMsg else "Please enter password for {0}@{1}: "
 	#
 
 	def __call__(self, machineName:str, loginName:str) -> str:
