@@ -6,7 +6,7 @@ import os
 
 import jk_json
 
-from .simple_encrypter import encryptPwd, decryptPwd
+from .simple_encrypter import encryptPwd, decryptPwd, isPwdEncrypted
 
 
 
@@ -15,10 +15,9 @@ from .simple_encrypter import encryptPwd, decryptPwd
 class OneSlotPasswordProvider(object):
 
 	def __init__(self, thePassword:str):
-		assert isinstance(thePassword, str)
-		assert thePassword
+		self.__pwd = ""
 
-		self.__pwd = thePassword
+		self.setPassword(thePassword)
 	#
 
 	def __call__(self, machineName:str, loginName:str) -> str:
@@ -35,5 +34,19 @@ class OneSlotPasswordProvider(object):
 			self.__pwd = decryptPwd(f.read())
 	#
 
+	def setPassword(self, thePassword:str):
+		assert isinstance(thePassword, str)
+		assert thePassword
+
+		if isPwdEncrypted(thePassword):
+			thePassword = decryptPwd(thePassword)
+
+		self.__pwd = thePassword
+	#
+
+	def getEncryptedPassword(self):
+		return encryptPwd(self.__pwd)
+	#
+
 #
 
